#!/bin/bash -e

echo "================= Adding some global settings ==================="
mkdir -p "$HOME/.ssh/"
mv /c7/config "$HOME/.ssh/"
cat /c7/90forceyes >> /etc/yum.conf
touch "$HOME/.ssh/known_hosts"
mkdir -p /etc/drydock

echo "================= Installing basic packages ================"

yum -y install  \
curl \
ftp \
gettext \
mercurial \
openssh-client \
openssl \
samba-client \
sudo \
unzip \
wget \
which

echo "================= Installing Python packages ==================="
sudo yum install -y epel-release
sudo yum install -y \
  python3-devel \
  python-pip

sudo pip3 install virtualenv==20.4.7
sudo pip3 install cryptography==3.3.2
sudo pip3 install -q pyOpenSSL==20.0.1


export JQ_VERSION=1.6*
echo "================= Adding JQ $JQ_VERSION ==================="
sudo yum install epel-release -y
sudo yum install -y jq-"$JQ_VERSION"

echo "================= Installing CLIs packages ======================"

export GIT_VERSION=2.31.1
echo "================= Installing Git $GIT_VERSION ===================="
sudo yum install -y http://opensource.wandisco.com/centos/7/git/x86_64/wandisco-git-release-7-2.noarch.rpm
sudo yum install -y git-"$GIT_VERSION"

echo "================= Installing Git lfs ===================="
sudo rpm -i c7/gitlfs.rpm

echo "================= Installing Node16  ===================="
NODEJS_VERSION=v16.16.0
mkdir /node16
pushd /node16
wget https://nodejs.org/dist/$NODEJS_VERSION/node-$NODEJS_VERSION-linux-x64.tar.xz
tar -xf node-$NODEJS_VERSION-linux-x64.tar.xz
ln -s /node16/node-$NODEJS_VERSION-linux-x64/bin/node /usr/local/bin/node16
popd
echo "Node16 version installed: $(node16 -v)"

echo '#!/bin/bash' > /usr/local/bin/node18
echo 'echo "node18 is not available. Trying node16." >&2' >> /usr/local/bin/node18
echo '/usr/local/bin/node16 "$@"' >> /usr/local/bin/node18
chmod +x /usr/local/bin/node18

echo "================= Adding gcloud =================="
tar -xf /c7/gcloudsdk.tar.gz
sudo ./google-cloud-sdk/install.sh -q --path-update true

export AWS_VERSION=1.19.103
echo "================= Adding awscli $AWS_VERSION ===================="
sudo pip install awscli=="$AWS_VERSION"

AZURE_CLI_VERSION=2.25*
echo "================ Adding azure-cli $AZURE_CLI_VERSION  =============="
sudo rpm --import https://packages.microsoft.com/keys/microsoft.asc
sudo sh -c 'echo -e "[azure-cli]\nname=Azure CLI\nbaseurl=https://packages.microsoft.com/yumrepos/azure-cli\nenabled=1\ngpgcheck=1\ngpgkey=https://packages.microsoft.com/keys/microsoft.asc" > /etc/yum.repos.d/azure-cli.repo'
sudo yum install -y azure-cli-$AZURE_CLI_VERSION

export JFROG_VERSION=1.54.1
echo "================= Adding jfrog-cli $JFROG_VERSION==================="
wget -nv https://releases.jfrog.io/artifactory/jfrog-cli/v1/"$JFROG_VERSION"/jfrog-cli-linux-amd64/jfrog?bt_package=jfrog-cli-linux-amd64 -O jfrog
sudo chmod +x jfrog
sudo mv jfrog /usr/bin/jfrog

KUBECTL_VERSION=1.24.0
echo "================= Adding kubectl "$KUBECTL_VERSION" ==================="
curl -LO https://storage.googleapis.com/kubernetes-release/release/v"$KUBECTL_VERSION"/bin/linux/amd64/kubectl
sudo chmod +x ./kubectl
sudo mv ./kubectl /usr/local/bin/kubectl

TF_VERSION=1.2.0
echo "================ Adding terraform- $TF_VERSION  ===================="
TF_FILE=terraform_"$TF_VERSION"_linux_amd64.zip

echo "Fetching terraform"
echo "-----------------------------------"
rm -rf /tmp/terraform
mkdir -p /tmp/terraform
wget -nv https://releases.hashicorp.com/terraform/$TF_VERSION/$TF_FILE
unzip -o $TF_FILE -d /tmp/terraform
sudo chmod +x /tmp/terraform/terraform
mv /tmp/terraform/terraform /usr/bin/terraform

PK_VERSION=1.8.0
echo "================ Adding packer $PK_VERSION  ===================="
PK_FILE=packer_"$PK_VERSION"_linux_amd64.zip

echo "Fetching packer"
echo "-----------------------------------"
# unlink required to avoid naming collision
unlink /usr/sbin/packer
rm -rf /tmp/packer
mkdir -p /tmp/packer
wget -nv https://releases.hashicorp.com/packer/$PK_VERSION/$PK_FILE
unzip -o $PK_FILE -d /tmp/packer
sudo chmod +x /tmp/packer/packer
mv /tmp/packer/packer /usr/bin/packer

echo "======= Adding docker compose ======="
sudo mv /c7/docker-compose /usr/local/bin/docker-compose
sudo chmod +x /usr/local/bin/docker-compose

HELM_VERSION=2.16.9
echo "================= helm 2 cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-amd64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-amd64/helm
chmod +x ./linux-amd64/tiller
sudo mv ./linux-amd64/helm /usr/local/bin/helm
sudo mv ./linux-amd64/tiller /usr/local/bin/tiller
rm -fr ./linux-amd64
rm -f helm.tar.gz

HELM_VERSION=3.9.0
echo "================= helm3 cli $HELM_VERSION ======================================"
curl -sSL -o helm.tar.gz https://get.helm.sh/helm-v"$HELM_VERSION"-linux-amd64.tar.gz
tar xzvf helm.tar.gz
chmod +x ./linux-amd64/helm
sudo mv ./linux-amd64/helm /usr/local/bin/helm3
rm -fr ./linux-amd64
rm -f helm.tar.gz

BUILDX_VERSION=0.10.5
echo "======================= buildx version $BUILDX_VERSION"
mkdir -p $HOME/.docker/cli-plugins
wget -O $HOME/.docker/cli-plugins/docker-buildx https://github.com/docker/buildx/releases/download/v"$BUILDX_VERSION"/buildx-v"$BUILDX_VERSION".linux-amd64
chmod +x $HOME/.docker/cli-plugins/docker-buildx
